@@ -32,6 +32,22 @@ from skyalmanac.lib import config as config
 from skyalmanac.lib import increments as increments
 from skyalmanac.lib.alma_skyfield import init_sf as init_sf
 
+
+def makePDF(fn, msg = ""):
+    command = 'pdflatex {}'.format(fn + ".tex")
+    os.system(command)
+    print("finished" + msg)
+    return
+
+def tidy_up(fn):
+    os.remove(fn + ".tex")
+    if os.path.isfile(fn + ".log"):
+        os.remove(fn + ".log")
+    if os.path.isfile(fn + ".aux"):
+        os.remove(fn + ".aux")
+    return
+
+
 ##Main##
 if sys.version_info[0] < 3:
     raise Exception("Must be using Python 3")
@@ -88,17 +104,17 @@ if config.pgsz not in set(['A4', 'Letter']):
     sys.exit(0)
 
 s = input("""\nWhat do you want to create?:\n
-    1   Full nautical almanac   (for a year)
-    2   Just tables for the sun (for a year)
-    3   Nautical almanac   - 6 days from today
-    4   Tables for the sun - 30 days from today
+    1   Nautical Almanac   (for a year)
+    2   Sun tables only    (for a year)
+    3   Nautical almanac   -  6 days from today
+    4   Sun tables only    - 30 days from today
     5   "Increments and Corrections" tables (static data)
 """)
 
 if s in set(['1', '2', '3', '4', '5']):
     if int(s) < 3:
-        print("Please enter the year you want to create the nautical almanac")
-        years = input("  for as yyyy ... or the FIRST and LAST year as yyyy-yyyy\n")
+        print("Please enter the desired year")
+        years = input("  as yyyy ... or the FIRST and LAST year as yyyy-yyyy\n")
         if len(years)== 4:
             yearfr = years
             yearto = years
@@ -149,7 +165,7 @@ if s in set(['1', '2', '3', '4', '5']):
         else:
             DecFmt = '[old]'
 
-    if s == '1':
+    if s == '1':        # Nautical Almanac (for a year)
         print("Be patient - this may take a while.")
 ##        config.initLOG()		# initialize log file
         for yearint in range(int(yearfr),int(yearto)+1):
@@ -159,8 +175,8 @@ if s in set(['1', '2', '3', '4', '5']):
             print(msg)
 ##            config.writeLOG(msg)
             first_day = datetime.date(yearint, 1, 1)
-            filename = "almanac{}{}.tex".format(ff,year+DecFmt)
-            outfile = open(filename, mode="w", encoding="utf8")
+            fn = "almanac{}{}".format(ff,year+DecFmt)
+            outfile = open(fn + ".tex", mode="w", encoding="utf8")
             outfile.write(tables.almanac(first_day,122,df180,df360,dfcm))
             outfile.close()
             stop = time.time()
@@ -168,42 +184,30 @@ if s in set(['1', '2', '3', '4', '5']):
             print(msg)
 ##            config.writeLOG("\n\n" + msg + "\n")
             print()
-            command = 'pdflatex {}'.format(filename)
-            os.system(command)
-            print("finished creating nautical almanac for {}".format(year))
-            os.remove(filename)
-            if os.path.isfile("almanac{}{}.log".format(ff,year+DecFmt)):
-                os.remove("almanac{}{}.log".format(ff,year+DecFmt))
-            if os.path.isfile("almanac{}{}.aux".format(ff,year+DecFmt)):
-                os.remove("almanac{}{}.aux".format(ff,year+DecFmt))
-##        config.closeLOG()
+            makePDF(fn, " creating nautical almanac for {}".format(year))
+            tidy_up(fn)
+##        config.closeLOG()     # close log after the for-loop
 
-    elif s == '2':
+    elif s == '2':      # Sun Tables (for a year)
         for yearint in range(int(yearfr),int(yearto)+1):
             year = "{:4d}".format(yearint)  # year = "%4d" %yearint
-            msg = "\nCreating the sun tables only for the year {}".format(year)
+            msg = "\nCreating the sun tables for the year {}\n".format(year)
             print(msg)
             first_day = datetime.date(yearint, 1, 1)
-            filename = "sunalmanac{}{}.tex".format(ff,year+DecFmt)
-            outfile = open(filename, mode="w", encoding="utf8")
+            fn = "sunalmanac{}{}".format(ff,year+DecFmt)
+            outfile = open(fn + ".tex", mode="w", encoding="utf8")
             outfile.write(suntables.almanac(first_day,25,dfra))
             outfile.close()
-            command = 'pdflatex {}'.format(filename)
-            os.system(command)
-            print("finished creating sun tables for {}".format(year))
-            os.remove(filename)
-            if os.path.isfile("sunalmanac{}{}.log".format(ff,year+DecFmt)):
-                os.remove("sunalmanac{}{}.log".format(ff,year+DecFmt))
-            if os.path.isfile("sunalmanac{}{}.aux".format(ff,year+DecFmt)):
-                os.remove("sunalmanac{}{}.aux".format(ff,year+DecFmt))
+            makePDF(fn, " creating sun tables for {}".format(year))
+            tidy_up(fn)
 
-    elif s == '3':
+    elif s == '3':      # Nautical almanac   -  6 days from today
 ##        config.initLOG()		# initialize log file
         start = time.time()
-        msg = "\nCreating nautical almanac tables - from {}".format(sdmy)
+        msg = "\nCreating nautical almanac tables - from {}\n".format(sdmy)
         print(msg)
-        filename = "almanac{}{}.tex".format(ff,symd+DecFmt)
-        outfile = open(filename, mode="w", encoding="utf8")
+        fn = "almanac{}{}".format(ff,symd+DecFmt)
+        outfile = open(fn + ".tex", mode="w", encoding="utf8")
         outfile.write(tables.almanac(first_day,2,df180,df360,dfcm))
         outfile.close()
         stop = time.time()
@@ -212,45 +216,28 @@ if s in set(['1', '2', '3', '4', '5']):
 ##        config.writeLOG('\n\n' + msg)
 ##        config.closeLOG()
         print()
-        command = 'pdflatex {}'.format(filename)
-        os.system(command)
-        print("finished")
-        os.remove(filename)
-        if os.path.isfile("almanac{}{}.log".format(ff,symd+DecFmt)):
-            os.remove("almanac{}{}.log".format(ff,symd+DecFmt))
-        if os.path.isfile("almanac{}{}.aux".format(ff,symd+DecFmt)):
-            os.remove("almanac{}{}.aux".format(ff,symd+DecFmt))
+        makePDF(fn)
+        tidy_up(fn)
 
-    elif s == '4':
-        msg = "\nCreating the sun tables only - from {}".format(sdmy)
+    elif s == '4':      # Sun tables only    - 30 days from today
+        msg = "\nCreating the sun tables - from {}\n".format(sdmy)
         print(msg)
-        filename = "sunalmanac{}{}.tex".format(ff,symd+DecFmt)
-        outfile = open(filename, mode="w", encoding="utf8")
+        fn = "sunalmanac{}{}".format(ff,symd+DecFmt)
+        outfile = open(fn + ".tex", mode="w", encoding="utf8")
         outfile.write(suntables.almanac(first_day,2,dfra))
         outfile.close()
-        command = 'pdflatex {}'.format(filename)
-        os.system(command)
-        print("finished")
-        os.remove(filename)
-        if os.path.isfile("sunalmanac{}{}.log".format(ff,symd+DecFmt)):
-            os.remove("sunalmanac{}{}.log".format(ff,symd+DecFmt))
-        if os.path.isfile("sunalmanac{}{}.aux".format(ff,symd+DecFmt)):
-            os.remove("sunalmanac{}{}.aux".format(ff,symd+DecFmt))
+        makePDF(fn)
+        tidy_up(fn)
 
     elif s == '5':
-        msg = "\nCreating the Increments and Corrections tables"
+        msg = "\nCreating the Increments and Corrections tables\n"
         print(msg)
         fn = "inc"
-        filename = fn + ".tex"
-        outfile = open(filename, mode="w", encoding="utf8")
+        outfile = open(fn + ".tex", mode="w", encoding="utf8")
         outfile.write(increments.makelatex())
         outfile.close()
-        command = 'pdflatex {}'.format(filename)
-        os.system(command)
-        print("finished")
-        os.remove(fn + ".tex")
-        os.remove(fn + ".log")
-        os.remove(fn + ".aux")
+        makePDF(fn)
+        tidy_up(fn)
 
 else:
     print("Error! Choose 1, 2, 3, 4 or 5")
